From: Wakou Aoyama Date: 1999-03-23T03:01:23+09:00 Subject: [ruby-dev:6446] sub("string", "string") 青山です。 $ ruby -e 'p "a^a^a".split(/\^/)' ["a", "a", "a"] $ ruby -e 'p "a^a^a".split("^")' ["a", "a", "a"] $ time ruby -e '0.upto(30000){"a^a^a".split(/\^/)}' real 0m6.593s user 0m6.540s sys 0m0.040s $ time ruby -e '0.upto(30000){"a^a^a".split("^")} real 0m3.423s user 0m3.260s sys 0m0.050s という事で、String による split は劇的に速いようなのですが、 sub("string", "string") なんていうのはどうなんでしょうか? もし split のように倍速になったりするのなら欲しいような気もしますけど。 -- 青山 和光 Wakou Aoyama